@@ -72,10 +72,11 @@ def main() -> None:
     if args.source is not None:
         if args.source.endswith(".py"):
             args.source = args.source[:-3]
+        ideas.source_file = args.source
         module = import_module(args.source)
         if sys.flags.interactive:  # pragma: no cover
-            console.start(locals=module.__dict__)
+            console.start(locals=module.__dict__, prompt=">>> ")
     else:
-	    console.start()
+	    console.start(prompt=">>> ")
 
 main()
\ No newline at end of file
